@@ -41,25 +41,5 @@ const textures = {
   },
 };
 
-const wall = ElementsFactories.WallFactory('wall', info, textures);
-
-let textureValues = {
-  'none': 'None'
-};
-
-wall.properties.textureA = {
-  label: 'Covering A',
-  type: 'enum',
-  defaultValue: 'bricks',
-  values: textureValues
-};
-
-wall.properties.textureB = {
-  label: 'Covering B',
-  type: 'enum',
-  defaultValue: 'bricks',
-  values: textureValues
-};
-
-export default wall;
+export default ElementsFactories.WallFactory('wall', info, textures);
 
