@@ -15,44 +15,44 @@ export function selectToolDrawingLine(sceneComponentType) {
   };
 }
 
-export function beginDrawingLine(layerID, x, y, detectSnap) {
+export function beginDrawingLine(layerID, x, y, snapMask) {
   return {
     type: BEGIN_DRAWING_LINE,
-    layerID: layerID, x: x, y: y, detectSnap: detectSnap
+    layerID: layerID, x: x, y: y, snapMask: snapMask
   };
 }
 
-export function updateDrawingLine(x, y, detectSnap) {
+export function updateDrawingLine(x, y, snapMask) {
   return {
     type: UPDATE_DRAWING_LINE,
-    x: x, y: y, detectSnap: detectSnap
+    x: x, y: y, snapMask: snapMask
   };
 }
 
-export function endDrawingLine(x, y, detectSnap) {
+export function endDrawingLine(x, y, snapMask) {
   return {
     type: END_DRAWING_LINE,
-    x: x, y: y, detectSnap: detectSnap
+    x: x, y: y, snapMask: snapMask
   };
 }
 
-export function beginDraggingLine(layerID, lineID, x, y, detectSnap) {
+export function beginDraggingLine(layerID, lineID, x, y, snapMask) {
   return {
     type: BEGIN_DRAGGING_LINE,
-    layerID: layerID, lineID: lineID, x: x, y: y, detectSnap: detectSnap
+    layerID: layerID, lineID: lineID, x: x, y: y, snapMask: snapMask
   };
 }
 
-export function updateDraggingLine(x, y, detectSnap) {
+export function updateDraggingLine(x, y, snapMask) {
   return {
     type: UPDATE_DRAGGING_LINE,
-    x: x, y: y, detectSnap: detectSnap
+    x: x, y: y, snapMask: snapMask
   };
 }
 
-export function endDraggingLine(x, y, detectSnap) {
+export function endDraggingLine(x, y, snapMask) {
   return {
     type: END_DRAGGING_LINE,
-    x: x, y: y, detectSnap: detectSnap
+    x: x, y: y, snapMask: snapMask
   };
 }
\ No newline at end of file
