@@ -16,10 +16,15 @@ export function parseData(sceneData, actions, catalog) {
   };
 
   planData.plan = new Three.Object3D();
+  planData.plan.name = 'plan';
 
   // Add a grid to the plan
   planData.grid = createGrid(sceneData);
+  planData.grid.name = 'grid';
+
   planData.boundingBox = new Three.Box3().setFromObject(planData.grid);
+  planData.boundingBox.name = 'boundingBox';
+
   var promises = [];
 
   sceneData.layers.forEach(function (layer) {
@@ -475,6 +480,7 @@ function addHole(sceneData, planData, layer, holeID, catalog, holesActions) {
     }
 
     var pivot = new Three.Object3D();
+    pivot.name = 'pivot';
     pivot.add(object);
 
     var line = layer.lines.get(holeData.line);
@@ -561,6 +567,7 @@ function addLine(sceneData, planData, layer, lineID, catalog, linesActions) {
     }
 
     var pivot = new Three.Object3D();
+    pivot.name = 'pivot';
     pivot.add(line3D);
 
     pivot.position.x = vertex0.x;
@@ -617,6 +624,7 @@ function addArea(sceneData, planData, layer, areaID, catalog, areaActions) {
     }
 
     var pivot = new Three.Object3D();
+    pivot.name = 'pivot';
     pivot.add(area3D);
     pivot.position.y = layer.altitude;
     planData.plan.add(pivot);
@@ -656,6 +664,7 @@ function addItem(sceneData, planData, layer, itemID, catalog, itemsActions) {
     }
 
     var pivot = new Three.Object3D();
+    pivot.name = 'pivot';
     pivot.add(item3D);
 
     pivot.rotation.y = item.rotation * Math.PI / 180;
