@@ -1,12 +1,13 @@
 import React from 'react';
+import * as SharedStyle from '../../shared-style';
 
 const BASE_STYLE = {
   display: "block",
   width: "100%",
   padding: "0px 4px",
   fontSize: "13px",
-  color: "#55595c",
-  backgroundColor: "#fff",
+  color: SharedStyle.PRIMARY_COLOR.input,
+  backgroundColor: SharedStyle.COLORS.white,
   backgroundImage: "none",
   border: "1px solid rgba(0,0,0,.15)",
   outline: "none",
