@@ -1,4 +1,4 @@
-import React, {Component} from 'react';
+import React, { Component } from 'react';
 import * as SharedStyle from '../../shared-style';
 
 const STYLE_INPUT = {
@@ -7,7 +7,7 @@ const STYLE_INPUT = {
   padding: '0 2px',
   fontSize: '13px',
   lineHeight: '1.25',
-  color: '#55595c',
+  color: SharedStyle.PRIMARY_COLOR.input,
   backgroundColor: SharedStyle.COLORS.white,
   backgroundImage: 'none',
   border: '1px solid rgba(0,0,0,.15)',
@@ -20,21 +20,22 @@ export default class FormTextInput extends Component {
 
   constructor(props) {
     super(props);
-    this.state = {focus: false};
+    this.state = { focus: false };
   }
 
   render() {
-    let {style, ...rest} = this.props;
+    let { style, ...rest } = this.props;
+
+    let textInputStyle = { ...STYLE_INPUT, ...style };
+    if (this.state.focus) textInputStyle.border = `1px solid ${SharedStyle.SECONDARY_COLOR.main}`;
 
     return <input
-      onFocus={e => this.setState({focus: true})}
-      onBlur={e => this.setState({focus: false})}
-      style={{
-        ...STYLE_INPUT,
-        ...style,
-        border: this.state.focus ? '1px solid #66afe9' : '1px solid rgba(0,0,0,.15)'
-      }}
-      type="text" {...rest}/>
+      onFocus={e => this.setState({ focus: true })}
+      onBlur={e => this.setState({ focus: false })}
+      style={textInputStyle}
+      type="text"
+      {...rest}
+    />
   }
 }
 
