@@ -407,9 +407,6 @@ OBJLoader.prototype = {
   },
 
   parse: function (text) {
-
-    console.time('OBJLoader');
-
     let state = this._createParserState();
 
     if (text.indexOf('\r\n') !== -1) {
@@ -712,8 +709,6 @@ OBJLoader.prototype = {
 
     }
 
-    console.timeEnd('OBJLoader');
-
     return container;
 
   }
