@@ -3,10 +3,12 @@ import {
   unselectAll,
 } from '../utils/layer-operations';
 
+import {history} from '../utils/export';
+
 import {SELECT_AREA} from '../constants';
 
 export default function (state, action) {
-  switch(action.type){
+  switch (action.type) {
     case SELECT_AREA:
       return selectArea(state, action.layerID, action.areaID);
 
@@ -19,9 +21,13 @@ export default function (state, action) {
 function selectArea(state, layerID, areaID) {
   let scene = state.scene;
 
+  scene = scene.merge({
+    layers: scene.layers.map(unselectAll),
+    selectedLayer: layerID
+  });
+
   scene = scene.updateIn(['layers', layerID], layer => layer.withMutations(layer => {
       let area = layer.getIn(['areas', areaID]);
-      unselectAll(layer);
       select(layer, 'areas', areaID);
       area.vertices.forEach(vertexID => select(layer, 'vertices', vertexID));
     })
@@ -29,6 +35,6 @@ function selectArea(state, layerID, areaID) {
 
   return state.merge({
     scene,
-    sceneHistory: state.sceneHistory.push(scene)
-  })
+    sceneHistory: history.historyPush( state.sceneHistory, scene )
+  });
 }
