@@ -14,7 +14,11 @@ import {
   MODE_DRAGGING_HOLE,
 } from '../constants';
 
-import * as Geometry from '../utils/geometry';
+import {
+  history,
+  GeometryUtils
+} from '../utils/export';
+
 import {
   select,
   unselect,
@@ -22,7 +26,16 @@ import {
   addHole,
   removeHole,
 } from '../utils/layer-operations';
-import {nearestSnap, addPointSnap, addLineSnap, addLineSegmentSnap, SNAP_POINT, SNAP_LINE, SNAP_SEGMENT} from '../utils/snap';
+
+import {
+  nearestSnap,
+  addPointSnap,
+  addLineSnap,
+  addLineSegmentSnap,
+  SNAP_POINT,
+  SNAP_LINE,
+  SNAP_SEGMENT
+} from '../utils/snap';
 
 export default function (state, action) {
   switch (action.type) {
@@ -59,7 +72,7 @@ function selectToolDrawingHole(state, sceneComponentType) {
 
     lines.forEach(line => {
       let {x: x1, y: y1} = vertices.get(line.vertices.get(0));
-      let {x: x2, y:y2} = vertices.get(line.vertices.get(1));
+      let {x: x2, y: y2} = vertices.get(line.vertices.get(1));
 
       addLineSegmentSnap(snapElements, x1, y1, x2, y2, 20, 1, line.id);
     })
@@ -80,7 +93,7 @@ function updateDrawingHole(state, layerID, x, y) {
 
   //calculate snap and overwrite coords if needed
   //force snap to segment
-  let snap = nearestSnap(state.snapElements, x, y, state.snapMask.merge({SNAP_SEGMENT:true}));
+  let snap = nearestSnap(state.snapElements, x, y, state.snapMask.merge({SNAP_SEGMENT: true}));
   if (snap) ({x, y} = snap.point);
 
   let scene = state.scene.updateIn(['layers', layerID], layer => layer.withMutations(layer => {
@@ -94,18 +107,17 @@ function updateDrawingHole(state, layerID, x, y) {
       let lineID = snap.snap.related.get(0);
       let line = layer.getIn(['lines', lineID]);
       let {x: x1, y: y1} = layer.vertices.get(line.vertices.get(0));
-      let {x: x2, y:y2} = layer.vertices.get(line.vertices.get(1));
+      let {x: x2, y: y2} = layer.vertices.get(line.vertices.get(1));
 
       // I need min and max vertices on this line segment
-      let minVertex = Geometry.minVertex({x: x1, y: y1}, {x: x2, y: y2});
-      let maxVertex = Geometry.maxVertex({x: x1, y: y1}, {x: x2, y: y2});
-      let width = catalog.factoryElement(state.drawingSupport.get('type'), {}, {}).properties.get('width').get('length');
-
+      let minVertex = GeometryUtils.minVertex({x: x1, y: y1}, {x: x2, y: y2});
+      let maxVertex = GeometryUtils.maxVertex({x: x1, y: y1}, {x: x2, y: y2});
+      let width = catalog.factoryElement(state.drawingSupport.get('type')).properties.getIn(['width','length']);
 
       // Now I need min and max possible coordinates for the hole on the line. They depend on the width of the hole
 
       // let width = hole.properties.get('width').get('length');
-      let lineLength = Geometry.pointsDistance(x1, y1, x2, y2);
+      let lineLength = GeometryUtils.pointsDistance(x1, y1, x2, y2);
       let alpha = Math.atan2(Math.abs(y2 - y1), Math.abs(x2 - x1));
 
       let cosWithThreshold = (alpha) => {
@@ -133,11 +145,11 @@ function updateDrawingHole(state, layerID, x, y) {
 
       let offset;
       if (x < minLeftVertexHole.x) {
-        offset = Geometry.pointPositionOnLineSegment(minVertex.x, minVertex.y,
+        offset = GeometryUtils.pointPositionOnLineSegment(minVertex.x, minVertex.y,
           maxVertex.x, maxVertex.y,
           minLeftVertexHole.x, minLeftVertexHole.y);
       } else if (x > maxRightVertexHole.x) {
-        offset = Geometry.pointPositionOnLineSegment(minVertex.x, minVertex.y,
+        offset = GeometryUtils.pointPositionOnLineSegment(minVertex.x, minVertex.y,
           maxVertex.x, maxVertex.y,
           maxRightVertexHole.x, maxRightVertexHole.y);
       } else {
@@ -145,24 +157,24 @@ function updateDrawingHole(state, layerID, x, y) {
         if (x === minLeftVertexHole.x && x === maxRightVertexHole.x) {
 
           if (y < minLeftVertexHole.y) {
-            offset = Geometry.pointPositionOnLineSegment(minVertex.x, minVertex.y,
+            offset = GeometryUtils.pointPositionOnLineSegment(minVertex.x, minVertex.y,
               maxVertex.x, maxVertex.y,
               minLeftVertexHole.x, minLeftVertexHole.y);
             offset = minVertex.x === x1 && minVertex.y === y1 ? offset : 1 - offset;
           } else if (y > maxRightVertexHole.y) {
-            offset = Geometry.pointPositionOnLineSegment(minVertex.x, minVertex.y,
+            offset = GeometryUtils.pointPositionOnLineSegment(minVertex.x, minVertex.y,
               maxVertex.x, maxVertex.y,
               maxRightVertexHole.x, maxRightVertexHole.y);
             offset = minVertex.x === x1 && minVertex.y === y1 ? offset : 1 - offset;
           } else {
-            offset = Geometry.pointPositionOnLineSegment(x1, y1, x2, y2, x, y);
+            offset = GeometryUtils.pointPositionOnLineSegment(x1, y1, x2, y2, x, y);
           }
         } else {
-          offset = Geometry.pointPositionOnLineSegment(x1, y1, x2, y2, x, y);
+          offset = GeometryUtils.pointPositionOnLineSegment(x1, y1, x2, y2, x, y);
         }
       }
 
-      // let offset = Geometry.pointPositionOnLineSegment(x1, y1, x2, y2, x, y);
+      // let offset = GeometryUtils.pointPositionOnLineSegment(x1, y1, x2, y2, x, y);
       let {hole} = addHole(layer, state.drawingSupport.get('type'), lineID, offset, catalog);
       select(layer, 'holes', hole.id);
     }
@@ -178,7 +190,7 @@ function endDrawingHole(state, layerID, x, y) {
   let scene = state.scene.updateIn(['layers', layerID], layer => unselectAll(layer));
   return state.merge({
     scene,
-    sceneHistory: state.sceneHistory.push(scene)
+    sceneHistory: history.historyPush( state.sceneHistory, scene )
   });
 }
 
@@ -207,7 +219,7 @@ function updateDraggingHole(state, x, y) {
 
   //calculate snap and overwrite coords if needed
   //force snap to segment
-  let snap = nearestSnap(state.snapElements, x, y, state.snapMask.merge({SNAP_SEGMENT:true}));
+  let snap = nearestSnap(state.snapElements, x, y, state.snapMask.merge({SNAP_SEGMENT: true}));
   if (!snap) return state;
 
   let {draggingSupport, scene} = state;
@@ -226,13 +238,13 @@ function updateDraggingHole(state, x, y) {
   ({x, y} = snap.point);
 
   // I need min and max vertices on this line segment
-  let minVertex = Geometry.minVertex(v0, v1);
-  let maxVertex = Geometry.maxVertex(v0, v1);
+  let minVertex = GeometryUtils.minVertex(v0, v1);
+  let maxVertex = GeometryUtils.maxVertex(v0, v1);
 
   // Now I need min and max possible coordinates for the hole on the line. They depend on the width of the hole
 
   let width = hole.properties.get('width').get('length');
-  let lineLength = Geometry.pointsDistance(v0.x, v0.y, v1.x, v1.y);
+  let lineLength = GeometryUtils.pointsDistance(v0.x, v0.y, v1.x, v1.y);
   let alpha = Math.atan2(Math.abs(v1.y - v0.y), Math.abs(v1.x - v0.x));
 
   let cosWithThreshold = (alpha) => {
@@ -264,40 +276,40 @@ function updateDraggingHole(state, x, y) {
 
   if (x < minLeftVertexHole.x) {
     // Snap point is previous the the line
-    offset = Geometry.pointPositionOnLineSegment(minVertex.x, minVertex.y,
+    offset = GeometryUtils.pointPositionOnLineSegment(minVertex.x, minVertex.y,
       maxVertex.x, maxVertex.y,
       minLeftVertexHole.x, minLeftVertexHole.y);
   } else {
     // Snap point is after the line or on the line
     if (x > maxRightVertexHole.x) {
-      offset = Geometry.pointPositionOnLineSegment(minVertex.x, minVertex.y,
+      offset = GeometryUtils.pointPositionOnLineSegment(minVertex.x, minVertex.y,
         maxVertex.x, maxVertex.y,
         maxRightVertexHole.x, maxRightVertexHole.y);
     } else if (x === minLeftVertexHole.x && x === maxRightVertexHole.x) {
       // I am on a vertical line, I need to check y coordinates
       if (y < minLeftVertexHole.y) {
-        offset = Geometry.pointPositionOnLineSegment(minVertex.x, minVertex.y,
+        offset = GeometryUtils.pointPositionOnLineSegment(minVertex.x, minVertex.y,
           maxVertex.x, maxVertex.y,
           minLeftVertexHole.x, minLeftVertexHole.y);
 
         offset = minVertex === v0 ? offset : 1 - offset;
 
       } else if (y > maxRightVertexHole.y) {
-        offset = Geometry.pointPositionOnLineSegment(minVertex.x, minVertex.y,
+        offset = GeometryUtils.pointPositionOnLineSegment(minVertex.x, minVertex.y,
           maxVertex.x, maxVertex.y,
           maxRightVertexHole.x, maxRightVertexHole.y);
 
         offset = minVertex === v0 ? offset : 1 - offset;
 
       } else {
-        offset = Geometry.pointPositionOnLineSegment(minVertex.x, minVertex.y,
+        offset = GeometryUtils.pointPositionOnLineSegment(minVertex.x, minVertex.y,
           maxVertex.x, maxVertex.y,
           x, y);
 
         offset = minVertex === v0 ? offset : 1 - offset;
       }
     } else {
-      offset = Geometry.pointPositionOnLineSegment(minVertex.x, minVertex.y,
+      offset = GeometryUtils.pointPositionOnLineSegment(minVertex.x, minVertex.y,
         maxVertex.x, maxVertex.y,
         x, y);
     }
@@ -315,7 +327,7 @@ function endDraggingHole(state, x, y) {
   state = updateDraggingHole(state, x, y);
   return state.merge({
     mode: MODE_IDLE,
-    sceneHistory: state.sceneHistory.push(state.scene)
+    sceneHistory: history.historyPush( state.sceneHistory, state.scene )
   });
 }
 
@@ -333,6 +345,6 @@ function selectHole(state, layerID, holeID) {
 
   return state.merge({
     scene,
-    sceneHistory: state.sceneHistory.push(scene)
+    sceneHistory: history.historyPush( state.sceneHistory, scene )
   })
 }
